@@ -41,7 +41,7 @@ __author__ = "Liguo Wang"
 __copyright__ = "Copyleft"
 __credits__ = []
 __license__ = "GPL"
-__version__="1.0.8"
+__version__="1.0.9"
 __maintainer__ = "Liguo Wang"
 __email__ = "wang.liguo@mayo.edu"
 __status__ = "Development"
@@ -61,11 +61,13 @@ def main():
 	parser.add_option("-g","--group",action="store",type="string",dest="group_file",help="Comma-separated group file defining the biological groups of each sample. Different groups will be colored differently in the t-SNE plot. Supports a maximum of 20 groups.")
 	parser.add_option("-p","--perplexity",action="store",type='int', dest="perplexity_value", default=5, help="This is a tunable parameter of t-SNE, and has a profound effect on the resulting 2D map. Consider selecting a value between 5 and 50, and the selected value should be smaller than the number of samples (i.e., number of points on the t-SNE 2D map). Default = %default" )
 	parser.add_option("-n","--ncomponent",action="store",type='int', dest="n_components", default=2, help="Number of components. default=%default" )
-	parser.add_option("--n_iter",action="store",type='int', dest="n_iterations", default=5000, help="The maximum number of iterations for the optimization. Should be at least 250. default=%default" )
+	parser.add_option("--n_iter",action="store",type='int', dest="n_iterations", default=10000, help="The maximum number of iterations for the optimization. Should be at least 250. default=%default" )
 	parser.add_option("--learning_rate",action="store",type='float', dest="learning_rate", default=200.0, help="The learning rate for t-SNE is usually in the range [10.0, 1000.0]. If the learning rate is too high, the data may look like a ‘ball’ with any point approximately equidistant from its nearest neighbors. If the learning rate is too low, most points may look compressed in a dense cloud with few outliers. If the cost function gets stuck in a bad local minimum increasing the learning rate may help. default=%default" )
 	parser.add_option("-l","--label",action="store_true",default=False,dest="text_label",help="If True, sample ids will be added underneath the data point. default=%default")
 	parser.add_option("-c","--char",action="store",type='int', default=1, dest="plot_char",help="Ploting character: 1 = 'dot', 2 = 'circle'. default=%default")
 	parser.add_option("-a","--alpha",action="store",type='float', default=0.6, dest="plot_alpha",help="Opacity of dots. A value in [0,1]. default=%default")
+	parser.add_option("-s","--dotSize",action="store",type='float', default=1.5, dest="dot_size",help="Size of dot or circle. To reduce the dot/circle size, use a value of less than 1; to increase the dot/circle size, use a value greater than 1. default=%default")
+	parser.add_option("-t","--labelSize",action="store",type='float', default=0.6, dest="label_size",help="Size of the text labels. To reduce the text size, use a value of less than 1; to increase the text size, use a value greater than 1. default=%default")
 	parser.add_option("-x","--loc",action="store",type='int', default=1, dest="legend_location",help="Location of legend panel: 1 = 'topright', 2 = 'bottomright', 3 = 'bottomleft', 4 = 'topleft'. default=%default")
 	parser.add_option("-o","--output",action="store",type='string', dest="out_file",help="The prefix of the output file.")
 	
@@ -149,12 +151,12 @@ def main():
 	
 	if options.plot_alpha:
 		print ('library(scales)', file=ROUT)
-		print ('plot(PC1, PC2, col = alpha(Colors, %f), pch=%d, cex=1.5, main="t-SNE 2D map")' % (options.plot_alpha, pch[options.plot_char]), file=ROUT)
+		print ('plot(PC1, PC2, col = alpha(Colors, %f), pch=%d, cex=%f, main="t-SNE 2D map")' % (options.plot_alpha, pch[options.plot_char], options.dot_size), file=ROUT)
 	else:
-		print ('plot(PC1, PC2, col = Colors, pch=%d, cex=1.2, main="t-SNE 2D map")' % pch[options.plot_char], file=ROUT)	
-		#print ('plot(PC1, PC2, col = Colors, pch=%d, cex=1, main="t-SNE 2D map")' % pch[options.plot_char], file=ROUT)
+		print ('plot(PC1, PC2, col = Colors, pch=%d, cex=%f, main="t-SNE 2D map")' % (pch[options.plot_char], options.dot_size), file=ROUT)	
 	if options.text_label:
-		print ('text(PC1, PC2, labels=Sample_ID, col = Colors, cex=0.5, pos=1)', file=ROUT)
+		print ('text(PC1, PC2, labels=Sample_ID, col = Colors, cex=%f, pos=1)' % (options.label_size), file=ROUT)
+	
 	print ('legend("%s", legend=c(%s), col=c(%s), pch=%d,cex=1)' %  (legend_pos[options.legend_location], ','.join(['"' + str(i) + '"' for i in group_names]), ','.join(['"' + str(group_to_col[i]) + '"' for i in group_names]), pch[options.plot_char]), file=ROUT)
 	
 	
