@@ -95,6 +95,42 @@ class ParseBED:
 			return list(set(reblocks))
 		else:
 			return reblocks
+
+	def getPromoter(self,uniquify = True, up = 2500, down = 2500):
+		'''
+		Get promoters from BED-12 file.
+		uniquify: if the returned blocks should be uniquify. 
+		'''
+		
+		reblocks = []
+		for l in ireader.reader(self.f):
+			l = l.strip()
+			if l.startswith(('#','track','browser')):continue
+			f = l.split()
+			if len(f) < 12:
+				print ("Standard BED format has 12 columns.\n%s" % (BED), file=sys.stderr)
+				sys.exit(1)
+			chrom = f[0]
+			tx_st = int(f[1])
+			tx_end = int(f[2])
+			symbol =  "Promoter(%s)" % f[3]
+			strand = f[5]
+			if strand == '-':
+				tss = tx_end
+				promoter_start = tss - down
+				promoter_end = tss + up
+				if promoter_start < 0: promoter_start = 0
+			elif strand == '+':
+				tss = tx_st
+				promoter_start = tss - up
+				promoter_end = tss + down
+				if promoter_start < 0: promoter_start = 0				
+			reblocks.append([chrom, promoter_start, promoter_end])
+		#self.f.seek(0)
+		if uniquify:
+			return list(set(reblocks))
+		else:
+			return reblocks
 		
 	def getCDSExons(self,uniquify=True, stranded = True):
 		
